/* GNOME DB libary
 * Copyright (C) 2000 Chris Wiegand
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

namespace gda
{
	class Batch;
	class Command;
	class Connection;
	class Error;
	class ErrorList;
	class Field;
	class Recordset;
	class Value;
};

#include "gda-client.h"
#include "gda-batch.h"
#include "gda-command.h"
#include "gda-connection.h"
#include "gda-error.h"
#include "gda-field.h"
#include "gda-recordset.h"

#include "gdaBatch.h"
#include "gdaCommand.h"
#include "gdaConnection.h"
#include "gdaError.h"
#include "gdaErrorList.h"
#include "gdaField.h"
#include "gdaRecordset.h"
#include "gdaValue.h"
